<?php

namespace Drupal\ckeditor5_audio_plugin\Plugin\CKEditor5Plugin;

use Drupal\ckeditor5\Plugin\CKEditor5PluginConfigurableInterface;
use Drupal\ckeditor5\Plugin\CKEditor5PluginConfigurableTrait;
use Drupal\ckeditor5\Plugin\CKEditor5PluginDefault;
use Drupal\Component\Utility\Environment;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\ByteSizeMarkup;
use Drupal\editor\EditorInterface;

/**
 * CKEditor 5 Audio plugin.
 *
 * @internal
 *   Plugin classes are internal.
 */
class Audio extends CKEditor5PluginDefault implements CKEditor5PluginConfigurableInterface {

  use CKEditor5PluginConfigurableTrait;

  /**
   * {@inheritdoc}
   */
  public function getDynamicPluginConfig(array $static_plugin_config, EditorInterface $editor): array {
    $config = $this->getConfiguration();
    if (isset($config['ckeditor5_audio'])) {
      $static_plugin_config['ckeditor5_audio'] = $config['ckeditor5_audio'];
    }
    return $static_plugin_config;
  }

  /**
   * {@inheritdoc}
   *
   * @see \Drupal\editor\Form\EditorImageDialog
   * @see editor_audio_upload_settings_form()
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['status'] = [
      '#type' => 'checkbox',
      '#title' => t('Enable audio uploads'),
      '#default_value' => $this->configuration['ckeditor5_audio']['status'],
      '#attributes' => [
        'data-editor-audio-upload' => 'status',
      ],
      '#description' => t('When enabled, audio can only be uploaded. When disabled, audio can only be added by URL.'),
    ];
    $show_if_audio_uploads_enabled = [
      'visible' => [
        ':input[data-editor-audio-upload="status"]' => ['checked' => TRUE],
      ],
    ];

    $form['directory'] = [
      '#type' => 'textfield',
      '#default_value' => $this->configuration['ckeditor5_audio']['directory'],
      '#title' => t('Upload directory'),
      '#description' => t("A directory relative to Drupal's files directory where uploaded images will be stored."),
      '#states' => $show_if_audio_uploads_enabled,
    ];

    $default_max_size = ByteSizeMarkup::create(Environment::getUploadMaxSize());
    $form['max_size'] = [
      '#type' => 'textfield',
      '#default_value' => $this->configuration['ckeditor5_audio']['max_size'],
      '#title' => t('Maximum file size'),
      '#description' => t('If this is left empty, then the file size will be limited by the PHP maximum upload size of @size.', ['@size' => $default_max_size]),
      '#maxlength' => 20,
      '#size' => 10,
      '#states' => $show_if_audio_uploads_enabled,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['ckeditor5_audio']['status'] = $form_state->getValue('status');
    $this->configuration['ckeditor5_audio']['directory'] = $form_state->getValue('directory');
    $this->configuration['ckeditor5_audio']['max_size'] = $form_state->getValue('max_size');
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'ckeditor5_audio' => [
        'status' => FALSE,
        'directory' => 'inline-audio',
        'max_size' => '',
      ],
    ];
  }

}
